@@ -6,7 +6,7 @@ use warnings;
 
 use Data::Dumper;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # overload these operators to have special meaning when
 # operand(s) are Statistics::Running:
@@ -130,9 +130,10 @@ sub	_histogram_recalculate {
 sub	histogram_disable {
 	my $self = $_[0];
 
-	$self->{'num-bins'} = -1;
-	$self->{'bins'}->{'b'} = [];
-	$self->{'bins'}->{'c'} = [];
+	$self->{'histo'}->{'num-bins'} = -1;
+	$self->{'histo'}->{'bins'}->{'b'} = [];
+	$self->{'histo'}->{'bins'}->{'c'} = [];
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # returns the count in bin specified as 1st input param
 sub	histogram_count { return $_[0]->{'histo'}->{'c'}->[$_[1]] }
@@ -173,9 +174,10 @@ sub	histogram_enable {
 		# we re-create our own bins based on num-bins etc.
 		$self->_histogram_create_bins_from_spec($m1, $m2, $m3)
 	} else {
-		# no params, set all counts OF ALREADY EXISTING histogram to zero
+		# no params! we need params
 		print STDERR "enable_histogram() : failed to enable histogram because no histogram specification was supplied. Try enable_histogram({bin-width=>1, nun-bins=>10, left-boundary=>-5});\n";
 	}
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # set existing histogram to zero counts
 sub     histogram_reset {
@@ -184,6 +186,7 @@ sub     histogram_reset {
 	# no params, set all counts OF ALREADY EXISTING histogram to zero
 	my $m1 = $self->{'histo'}->{'bins'}->{'c'};
 	for(my $i=$self->{'histo'}->{'num-bins'};$i-->0;){ $m1->[$i] = 0 }
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # push Data: a sample and process/update mean and all other stat measures
 # also insert it in histogram
@@ -396,6 +399,7 @@ sub     _add_histograms {
 	for($i=$self->{'histo'}->{'num-bins'};$i-->0;){
 		$selfC->[$i] += $otherC->[$i];
 	}
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 	return 1 # counts added
 }
 # print object as a string, string concat/printing is overloaded on this method
@@ -435,6 +439,7 @@ sub     _histogram_create_bins_from_spec {
 	}
 	$self->{'histo'}->{'bins'}->{'b'} = \@B;
 	$self->{'histo'}->{'bins'}->{'c'} = [(0)x$nb];
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # add a datapoint to the histogram, this is usually called only via the public add()
 sub     _histogram_add {
@@ -504,6 +509,7 @@ sub     _hash2bins {
 	push(@B, $X[-1]);
 	$self->{'histo'}->{'bins'}->{'b'} = \@B;
 	$self->{'histo'}->{'bins'}->{'c'} = \@C;
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # given a hash with keys
 # to-bin -> count
@@ -526,6 +532,7 @@ sub     _stathash2bins {
 	}
 	$self->{'histo'}->{'bins'}->{'b'} = \@B;
 	$self->{'histo'}->{'bins'}->{'c'} = \@C;
+	$self->{'histo'}->{'needs-recalculate'} = 1;
 }
 # compares the structure of the histograms of us and another obj
 # if histograms have same number of bins and same bin-specs (boundaries)
